---
title: <span class="badge builder"></span> PulseWaveQuery
---
# <span class="badge builder"></span> PulseWaveQuery

## Constructor

```python
PulseWaveQuery()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> testdata.PulseWaveQuery
```

### <span class="badge object-method"></span> off_count

```python
def off_count(off_count: int) -> typing.Self
```

### <span class="badge object-method"></span> off_value

```python
def off_value(off_value: float) -> typing.Self
```

### <span class="badge object-method"></span> on_count

```python
def on_count(on_count: int) -> typing.Self
```

### <span class="badge object-method"></span> on_value

```python
def on_value(on_value: float) -> typing.Self
```

### <span class="badge object-method"></span> time_step

```python
def time_step(time_step: int) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [PulseWaveQuery](./object-PulseWaveQuery.md)
